Converts object of class sq to a class
from another package. Currently supported packages are ape,
bioseq, Bioconductor and seqinr. For exact list of
supported classes and resulting types, see details.
export_sq(x, export_format, name = NULL, ...)An object with the format specified in the parameter. To find information about the detailed structure of this object, see documentation of these objects.
[sq]
An object this function is applied to.
[character(1)]
A string indicating desired class (with specified package for clarity).
[character]
Vector of sequence names. Must be of the same length as sq object.
Can be NULL.
further arguments to be passed from or to other methods.
Currently supported formats are as follows (grouped by sq types):
ami:
"ape::AAbin"
"bioseq::bioseq_aa"
"Biostrings::AAString"
"Biostrings::AAStringSet"
"seqinr::SeqFastaAA"
dna:
"ape::DNAbin"
"bioseq::bioseq_dna"
"Biostrings::DNAString"
"Biostrings::DNAStringSet"
"seqinr::SeqFastadna"
rna:
"bioseq::bioseq_rna"
"Biostrings::RNAString"
"Biostrings::RNAStringSet"
sq class
Functions from output module:
as.character.sq(),
as.matrix.sq(),
as.sq(),
write_fasta()